@@ -1,4 +1,4 @@
-#' @title 27 experimental studies from from
+#' @title 27 experimental studies from
 #' \insertCite{anderson2010violent;textual}{RoBMA} that meet the best practice criteria
 #'
 #' @description The data set contains correlation coefficients, sample
@@ -16,7 +16,7 @@
 "Anderson2010"
 
 
-#' @title 9 experimental studies from from
+#' @title 9 experimental studies from
 #' \insertCite{bem2011feeling;textual}{RoBMA} as described in
 #' \insertCite{bem2011must;textual}{RoBMA}
 #'
@@ -32,3 +32,22 @@
 #' @references
 #' \insertAllCited{}
 "Bem2011"
+
+
+#' @title 5 studies with a tactile outcome assessment from
+#' \insertCite{poulsen2006potassium;textual}{RoBMA} of the effect of potassium-containing toothpaste
+#' on dentine hypersensitivity
+#'
+#' @description The data set contains Cohen's d effect sizes, standard errors,
+#' and labels for 5 studies assessing the tactile outcome from a meta-analysis of
+#' the effect of potassium-containing toothpaste on dentine hypersensitivity
+#' \insertCite{poulsen2006potassium}{RoBMA} which was used as an example in
+#' \insertCite{bartos2021bayesian;textual}{RoBMA}.
+#'
+#' @format A data.frame with 3 columns and 5 observations.
+#'
+#' @return a data.frame.
+#'
+#' @references
+#' \insertAllCited{}
+"Poulsen2006"
